function [yy]=interpol(x,y,xx)

%----------------------------------------------
% Interpolazione
%
% In input:
% x: nodi.
% y: valori nei nodi.
% xx nodi su cui calcolare l'interpolante.
% m: grado dell'approssimante ai minimi quadrati
%
% In output:
% yy: valori dell'interpolante o approssimante.
%----------------------------------------------

m=length(x)-1;
coeff=polyfit(x,y,m);
yy=polyval(coeff,xx);
